==> zio-aws-memorydb_3-5.17.155.1-sources.jar: zio/aws/memorydb/model/SubnetGroup.scala <==
package zio.aws.memorydb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class SubnetGroup(
    name: Option[String] = None,
    description: Option[String] = None,
    vpcId: Option[String] = None,
    subnets: Option[Iterable[zio.aws.memorydb.model.Subnet]] = None,
    arn: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.memorydb.model.SubnetGroup = {
    import SubnetGroup.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.memorydb.model.SubnetGroup
      .builder()
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(vpcId.map(value => value: java.lang.String))(_.vpcId)
      .optionallyWith(
        subnets.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.subnets)
      .optionallyWith(arn.map(value => value: java.lang.String))(_.arn)
      .build()
  }
  def asReadOnly: zio.aws.memorydb.model.SubnetGroup.ReadOnly =
    zio.aws.memorydb.model.SubnetGroup.wrap(buildAwsValue())
}
object SubnetGroup {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.memorydb.model.SubnetGroup
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.memorydb.model.SubnetGroup =
      zio.aws.memorydb.model.SubnetGroup(
        name.map(value => value),
        description.map(value => value),
        vpcId.map(value => value),
        subnets.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        arn.map(value => value)
      )
    def name: Option[String]
    def description: Option[String]
    def vpcId: Option[String]
    def subnets: Option[List[zio.aws.memorydb.model.Subnet.ReadOnly]]
    def arn: Option[String]
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getVpcId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("vpcId", vpcId)
    def getSubnets
        : ZIO[Any, AwsError, List[zio.aws.memorydb.model.Subnet.ReadOnly]] =
      AwsError.unwrapOptionField("subnets", subnets)
    def getArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("arn", arn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.memorydb.model.SubnetGroup
  ) extends zio.aws.memorydb.model.SubnetGroup.ReadOnly {
    override val name: Option[String] =
      scala.Option(impl.name()).map(value => value: String)
    override val description: Option[String] =
      scala.Option(impl.description()).map(value => value: String)
    override val vpcId: Option[String] =
      scala.Option(impl.vpcId()).map(value => value: String)
    override val subnets: Option[List[zio.aws.memorydb.model.Subnet.ReadOnly]] =
      scala
        .Option(impl.subnets())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.memorydb.model.Subnet.wrap(item)
          }.toList
        )
    override val arn: Option[String] =
      scala.Option(impl.arn()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.memorydb.model.SubnetGroup
  ): zio.aws.memorydb.model.SubnetGroup.ReadOnly = new Wrapper(impl)
}

==> zio-aws-memorydb_3-5.17.195.1-sources.jar: zio/aws/memorydb/model/SubnetGroup.scala <==
package zio.aws.memorydb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class SubnetGroup(
    name: Optional[String] = Optional.Absent,
    description: Optional[String] = Optional.Absent,
    vpcId: Optional[String] = Optional.Absent,
    subnets: Optional[Iterable[zio.aws.memorydb.model.Subnet]] =
      Optional.Absent,
    arn: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.memorydb.model.SubnetGroup = {
    import SubnetGroup.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.memorydb.model.SubnetGroup
      .builder()
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(vpcId.map(value => value: java.lang.String))(_.vpcId)
      .optionallyWith(
        subnets.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.subnets)
      .optionallyWith(arn.map(value => value: java.lang.String))(_.arn)
      .build()
  }
  def asReadOnly: zio.aws.memorydb.model.SubnetGroup.ReadOnly =
    zio.aws.memorydb.model.SubnetGroup.wrap(buildAwsValue())
}
object SubnetGroup {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.memorydb.model.SubnetGroup
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.memorydb.model.SubnetGroup =
      zio.aws.memorydb.model.SubnetGroup(
        name.map(value => value),
        description.map(value => value),
        vpcId.map(value => value),
        subnets.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        arn.map(value => value)
      )
    def name: Optional[String]
    def description: Optional[String]
    def vpcId: Optional[String]
    def subnets: Optional[List[zio.aws.memorydb.model.Subnet.ReadOnly]]
    def arn: Optional[String]
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getVpcId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("vpcId", vpcId)
    def getSubnets
        : ZIO[Any, AwsError, List[zio.aws.memorydb.model.Subnet.ReadOnly]] =
      AwsError.unwrapOptionField("subnets", subnets)
    def getArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("arn", arn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.memorydb.model.SubnetGroup
  ) extends zio.aws.memorydb.model.SubnetGroup.ReadOnly {
    override val name: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => value: String)
    override val description: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => value: String)
    override val vpcId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.vpcId())
      .map(value => value: String)
    override val subnets
        : Optional[List[zio.aws.memorydb.model.Subnet.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.subnets())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.memorydb.model.Subnet.wrap(item)
          }.toList
        )
    override val arn: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.memorydb.model.SubnetGroup
  ): zio.aws.memorydb.model.SubnetGroup.ReadOnly = new Wrapper(impl)
}
